@@ -5,6 +5,7 @@ from derobertis_cv.models.category import CategoryModel
 from derobertis_cv.models.grades.main import GradingModel
 from derobertis_cv.models.prereq import CoursePrerequsitesModel
 from derobertis_cv.models.textbook import TextbookModel
+from derobertis_cv.models.university import UniversityModel
 from derobertis_cv.pltemplates.software.project import SoftwareProject
 
 
@@ -17,7 +18,7 @@ class CourseModel:
     periods_taught: Optional[Sequence[str]] = None
     evaluation_score: Optional[float] = None
     evaluation_max_score: int = 5
-    university: Optional[str] = None
+    university: Optional[UniversityModel] = None
     course_id: Optional[str] = None
     textbook: Optional[TextbookModel] = None
     instructor: str = 'Nick DeRobertis'
