@@ -1,7 +1,7 @@
 
 # TODO [#1]: restructure into class
 
-UF = 'University of Florida'
+UF_NAME = 'University of Florida'
 WARRINGTON = 'Warrington College of Business Administration'
 FIRE = 'Department of Finance, Insurance, & Real Estate'
 UF_STREET_ADDRESS = 'PO Box 117168'
@@ -21,11 +21,11 @@ UF_CONTACT_LINES = [
 ]
 
 UF_WITH_CONTACT_LINES = [
-    UF,
+    UF_NAME,
     *UF_CONTACT_LINES
 ]
 
-VCU = 'Virginia Commonwealth University'
+VCU_NAME = 'Virginia Commonwealth University'
 
 
 ALABAMA = 'University of Alabama'
