@@ -5,11 +5,12 @@ import pyexlatex as pl
 from derobertis_cv.models.course import CourseModel
 from derobertis_cv.models.prereq import CoursePrerequsitesModel
 from derobertis_cv.models.textbook import TextbookModel
-from derobertis_cv.pldata.constants.institutions import UF
+from derobertis_cv.pldata.constants.institutions import UF_NAME
 from derobertis_cv.pldata.course_categories import COURSE_CATEGORIES, FIN_MODEL_COURSE_CATEGORIES, \
     FIN_MODEL_COURSE_MAIN_CATEGORIES
 from derobertis_cv.pldata.courses.general import get_grading_model
 from derobertis_cv.pldata.software import get_software_projects
+from derobertis_cv.pldata.universities import UF
 
 
 def get_fin_model_course(**overrides: Dict[str, Any]) -> CourseModel:
