@@ -15,7 +15,7 @@ from derobertis_cv.pldata.papers import (
     get_working_papers,
     get_works_in_progress, ResearchProjectModel
 )
-from derobertis_cv.pldata.skills import get_skills
+from derobertis_cv.pldata.skills import get_skills, get_skills_str_list
 from derobertis_cv.pldata.software import get_software_projects
 from derobertis_cv.pldata.awards import get_awards
 from derobertis_cv.pldata.interests import get_research_interests
@@ -44,6 +44,9 @@ class CVModel:
     excluded_software_projects: Optional[Sequence[str]] = None
     software_project_order: Optional[Sequence[str]] = None
     excluded_companies: Optional[Sequence[str]] = None
+    exclude_skills: Optional[Sequence[str]] = None
+    exclude_skill_children: bool = True
+    skill_order: Optional[Sequence[str]] = None
     professional_section_name: str = 'Professional Experience'
     overview_text: str = (
         'An entrepreneur, full-stack web engineer and architect, data scientist, empirical researcher, and '
@@ -117,7 +120,11 @@ def get_cv_contents(model: CVModel) -> List[ItemBase]:
             num_cols=2
         ),
         ResumeSection.SKILLS: pl.Section(
-            get_skills(),
+            get_skills_str_list(
+                exclude_skills=model.exclude_skills,
+                exclude_skill_children=model.exclude_skill_children,
+                order=model.skill_order,
+            ),
             title='Skills'
         ),
         ResumeSection.OVERVIEW: pl.Section(
